..
  NOTE: This RST file was generated by `make examples`.
  Do not edit it directly.
  See docs/source/examples/example_doc_generator.py

Context Menu Example
===============================================================================

An example of using the ``Menu`` widget as a context menu.

.. TIP:: To see this example in action, download it from
 :download:`context_menu <../../../examples/widgets/context_menu.enaml>`
 and run::

   $ enaml-run context_menu.enaml


Screenshot
-------------------------------------------------------------------------------

.. image:: images/ex_context_menu.png

Example Enaml Code
-------------------------------------------------------------------------------
.. literalinclude:: ../../../examples/widgets/context_menu.enaml
    :language: enaml
